==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/admin/messages/pl/base.php <==
<?php
return array (
  '<strong>Administration</strong> menu' => 'Menu<strong> administracji</strong>',
  '<strong>Maintenance</strong> Mode' => 'Tryb <strong>Serwisowy</strong>',
  '<strong>Module</strong> administration' => 'Administrowanie <strong>modułami</strong>',
  '<strong>Warning</strong> incomplete setup!' => '<strong>Ostrzeżenie</strong> niekompletne ustawienia!',
  'About' => 'O mnie',
  'Activate' => 'Aktywuj',
  'Active Modules' => 'Aktywuj Moduły',
  'Add more modules' => 'Dodaj więcej modułów',
  'Admin' => 'Admin',
  'Administration' => 'Administracja',
  'Administrative group' => 'Grupa administracyjna',
  'Administrators' => 'Administratorzy',
  'Advanced' => 'Zaawansowane',
  'Advanced settings' => 'Zaawansowane ustawienia',
  'Appearance' => 'Wygląd',
  'Approval' => 'Zatwierdzanie',
  'Authentication' => 'Uwieżytelnianie',
  'Back to overview' => 'Wróć do omówienia',
  'Back to user overview' => 'Wróć do przeglądu użytkownika',
  'Base URL needs to begin with http:// or https://' => 'Podstawowy adres URL musi zaczynać się od http:// lub https://',
  'Basic' => 'Podstawowe',
  'Caching' => 'Cache',
  'Configure' => 'Konfiguruj',
  'Cronjobs' => 'Zadania cron',
  'Deactivate' => 'Dezaktywuj',
  'Default' => 'Domyślna',
  'Default group for administrators of this HumHub Installation' => 'Domyślna grupa dla administratorów tej instancji Humhub\'a',
  'Default group for all newly registered users of the network' => 'Domyślna grupa dla nowo zarejestrowanych użytkowników sieci',
  'Delete all' => 'Usuń wszystkie',
  'Delete selected rows' => 'Usuń wybrane wiersze',
  'Design' => 'Wygląd',
  'Enable module...' => 'Włącz moduł...',
  'Files' => 'Pliki',
  'General' => 'Ogólne',
  'Groups' => 'Grupy',
  'Groups (Note: The Administrator group of this user can\'t be managed with your permissions)' => 'Grupy (Informacja: Administrator grupy tego użytkownika nie może być zarządzany z Twoim pozwoleniem)',
  'Inactive Modules' => 'Moduły nieaktywne',
  'Information' => 'Informacje',
  'Install Updates' => 'Zainstaluj aktualizacje',
  'Invalid user state: {state}' => 'Niepoprawny stan użytkownika: {state}',
  'Invite by email' => 'Zaproś przez e-mail',
  'Invite by link' => 'Zaproś poprzez link',
  'Invited by' => 'Zaproszony przez',
  'Keep your system up-to-date and benefit from the latest improvements.' => '',
  'Logging' => 'Logowanie',
  'Logs' => 'Logi',
  'Mailing' => 'Mailing',
  'Modules' => 'Moduły',
  'No modules installed yet. Install some to enhance the functionality!' => 'Brak zainstalowanych modułów. Zainstaluj jakieś aby zwiększyć funkcjonalność!',
  'Notifications' => 'Powiadomienia',
  'OEmbed' => 'OEmbed',
  'OEmbed providers' => 'Dostawcy OEmbed',
  'Open documentation' => 'Otwórz dokumentację',
  'Pending user registrations' => 'Użytkownicy oczekujący na akceptację',
  'People' => 'Ludzie',
  'Permissions' => 'Uprawnienia',
  'Proxy' => 'Serwer Proxy',
  'Self test' => 'Auto test',
  'Set as default' => 'Ustaw jako domyślny',
  'Settings' => 'Ustawienia',
  'Show in Marketplace' => '',
  'Sign up' => 'Zarejestruj się',
  'Spaces' => 'Strefy',
  'Statistics' => 'Statystyki',
  'The cron job for the background jobs (queue) does not seem to work properly.' => 'Zadanie cron dla zadań w tle (kolejka) prawdopodobnie nie wykonało się poprawnie.',
  'The cron job for the regular tasks (cron) does not seem to work properly.' => 'Zadanie cron dla normalnych zadań (cron) prawdopodobnie nie wykonało się poprawnie.',
  'This overview shows you all installed modules and allows you to enable, disable, configure and of course uninstall them. To discover new modules, take a look into our Marketplace. Please note that deactivating or uninstalling a module will result in the loss of any content that was created with that module.' => '',
  'Uninstall' => 'Odinstaluj',
  'Updates available for {count} of your modules' => 'Aktualizacje dostępne dla {count} z Twoich modułów',
  'User not found!' => 'Użytkownik nie znaleziony!',
  'Userprofiles' => 'Profile użytkowników',
  'Users' => 'Użytkownicy',
  'Version' => 'Wersja',
  'Visit Marketplace' => '',
  'You do not have the permission to configure modules. Please contact the administrator for further information.' => '',
  'You do not have the permission to manage modules. Please contact the administrator for further information.' => 'Nie masz uprawnień do zarządzania modułami. Skontaktuj się z administratorem po więcej informacji.',
);

==> humhub-1.16.2.tar.gz: humhub-1.16.2/protected/humhub/modules/admin/messages/pl/base.php <==
<?php
return array (
  '<strong>Administration</strong> menu' => 'Menu<strong> administracji</strong>',
  '<strong>Maintenance</strong> Mode' => 'Tryb <strong>Serwisowy</strong>',
  '<strong>Module</strong> administration' => 'Administrowanie <strong>modułami</strong>',
  '<strong>Warning</strong> incomplete setup!' => '<strong>Ostrzeżenie</strong> niekompletne ustawienia!',
  'About' => 'O mnie',
  'Active Modules' => 'Aktywuj Moduły',
  'Add more modules' => 'Dodaj więcej modułów',
  'Admin' => 'Admin',
  'Administration' => 'Administracja',
  'Administrative group' => 'Grupa administracyjna',
  'Administrators' => 'Administratorzy',
  'Advanced' => 'Zaawansowane',
  'Advanced settings' => 'Zaawansowane ustawienia',
  'Appearance' => 'Wygląd',
  'Approval' => 'Zatwierdzanie',
  'Authentication' => 'Uwieżytelnianie',
  'Back to overview' => 'Wróć do omówienia',
  'Back to user overview' => 'Wróć do przeglądu użytkownika',
  'Basic' => 'Podstawowe',
  'Caching' => 'Cache',
  'Configure' => 'Konfiguruj',
  'Cronjobs' => 'Zadania cron',
  'Default' => 'Domyślna',
  'Default group for administrators of this HumHub Installation' => 'Domyślna grupa dla administratorów tej instancji Humhub\'a',
  'Default group for all newly registered users of the network' => 'Domyślna grupa dla nowo zarejestrowanych użytkowników sieci',
  'Delete all' => 'Usuń wszystkie',
  'Delete selected rows' => 'Usuń wybrane wiersze',
  'Design' => 'Wygląd',
  'Disable' => 'Dezaktywuj',
  'Enable' => 'Aktywuj',
  'Enable module...' => 'Włącz moduł...',
  'Files' => 'Pliki',
  'General' => 'Ogólne',
  'Groups' => 'Grupy',
  'Groups (Note: The Administrator group of this user can\'t be managed with your permissions)' => 'Grupy (Informacja: Administrator grupy tego użytkownika nie może być zarządzany z Twoim pozwoleniem)',
  'Inactive Modules' => 'Moduły nieaktywne',
  'Information' => 'Informacje',
  'Install Updates' => 'Zainstaluj aktualizacje',
  'Invalid user state: {state}' => 'Niepoprawny stan użytkownika: {state}',
  'Invite by email' => 'Zaproś przez e-mail',
  'Invite by link' => 'Zaproś poprzez link',
  'Invited by' => 'Zaproszony przez',
  'Keep your system up-to-date and benefit from the latest improvements.' => 'Bądź na czasie z aktualizacjami systemu aby korzystać z najnowszych usprawnień.',
  'Logging' => 'Logowanie',
  'Logs' => 'Logi',
  'Mailing' => 'Mailing',
  'Modules' => 'Moduły',
  'No modules installed yet. Install some to enhance the functionality!' => 'Brak zainstalowanych modułów. Zainstaluj jakieś aby zwiększyć funkcjonalność!',
  'Notifications' => 'Powiadomienia',
  'OEmbed' => 'OEmbed',
  'OEmbed providers' => 'Dostawcy OEmbed',
  'Open documentation' => 'Otwórz dokumentację',
  'Pending user registrations' => 'Użytkownicy oczekujący na akceptację',
  'People' => 'Ludzie',
  'Permissions' => 'Uprawnienia',
  'Proxy' => 'Serwer Proxy',
  'Self test' => 'Auto test',
  'Set as default' => 'Ustaw jako domyślny',
  'Settings' => 'Ustawienia',
  'Show in Marketplace' => 'Pokaż w rynku',
  'Sign up' => 'Zarejestruj się',
  'Spaces' => 'Strefy',
  'Statistics' => 'Statystyki',
  'The cron job for the background jobs (queue) does not seem to work properly.' => 'Zadanie cron dla zadań w tle (kolejka) prawdopodobnie nie wykonało się poprawnie.',
  'The cron job for the regular tasks (cron) does not seem to work properly.' => 'Zadanie cron dla normalnych zadań (cron) prawdopodobnie nie wykonało się poprawnie.',
  'This overview shows you all installed modules and allows you to enable, disable, configure and of course uninstall them. To discover new modules, take a look into our Marketplace. Please note that deactivating or uninstalling a module will result in the loss of any content that was created with that module.' => 'To zestawienie zawiera wszystkie zainstalowane moduły. Możesz je włączyć, wyłączyć, skonfigurować a także odinstalować. W ramach ryneczku odnajdziesz nowości. Miej na uwadze, że wyłączając czy odinstalując moduł zniknie część treści - ta dodana przy jego użyciu.',
  'Uninstall' => 'Odinstaluj',
  'Updates available for {count} of your modules' => 'Aktualizacje dostępne dla {count} z Twoich modułów',
  'User not found!' => 'Użytkownik nie znaleziony!',
  'Userprofiles' => 'Profile użytkowników',
  'Users' => 'Użytkownicy',
  'Version' => 'Wersja',
  'Visit Marketplace' => 'Odwiedź rynek',
  'You do not have the permission to configure modules. Please contact the administrator for further information.' => 'Nie masz uprawnień do konfigurowania modułów. Skontaktuj się z administratorem aby wyjaśnić sprawę.',
  'You do not have the permission to manage modules. Please contact the administrator for further information.' => 'Nie masz uprawnień do zarządzania modułami. Skontaktuj się z administratorem po więcej informacji.',
);
